# Pharaoh

[![PyPI](https://img.shields.io/pypi/v/pharaoh-report)](https://pypi.org/project/pharaoh-report/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/pharaoh-report.svg)](https://pypi.org/project/pharaoh-report/)
[![image](https://img.shields.io/pypi/l/pharaoh-report.svg)](https://pypi.python.org/pypi/pharaoh-report)
[![image](https://github.com/Infineon/pharaoh-dev/actions/workflows/documentation.yml/badge.svg)](https://github.com/Infineon/pharaoh-dev/actions/workflows/documentation.yml)
[![image](https://github.com/Infineon/pharaoh-dev/actions/workflows/matrix_tests.yml/badge.svg)](https://github.com/Infineon/pharaoh-dev/actions/workflows/matrix_tests.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/Infineon/pharaoh-dev/main.svg)](https://results.pre-commit.ci/latest/github/Infineon/pharaoh-dev/main)


<img src="https://github.com/Infineon/pharaoh-dev/blob/main/docs/_static/icon.png" height="200">

Pharaoh is a [Sphinx](https://www.sphinx-doc.org/en/master/)-based Python framework
for generating reports in various formats by combining the
power of configurable [Jinja](https://jinja.palletsprojects.com/en/3.1.x/)
templates and Python scripts for asset generation.

Please refer to the [official documentation](https://infineon.github.io/pharaoh-dev/).

<img src="https://github.com/Infineon/pharaoh-dev/blob/main/docs/_static/overview.png">
